| SimpleSBM_fit_noCov | R Documentation |
It is not designed to be called directly by the user.
sbm::SBM -> sbm::SimpleSBM -> SimpleSBM_fit -> SimpleSBM_fit_noCov
imputationthe matrix of imputed values
vExpecdouble: variational approximation of the expectation complete log-likelihood
vExpec_correcteddouble: variational approximation of the expectation complete log-likelihood with correction to be comparable with MNAR criteria
SimpleSBM_fit_noCov$update_parameters()update parameters estimation (M-step)
SimpleSBM_fit_noCov$update_parameters(...)
...additional arguments, only required for MNAR cases
SimpleSBM_fit_noCov$update_blocks()update variational estimation of blocks (VE-step)
SimpleSBM_fit_noCov$update_blocks(...)
...additional arguments, only required for MNAR cases
SimpleSBM_fit_noCov$polish_log_tau()for each node, the complete-data log-likelihood it would contribute to
each class if hard-assigned there (theta/pi held fixed), used to decide node-swap
moves in missSBM_fit$polish().
SimpleSBM_fit_noCov$polish_log_tau(log_lambda = 0)
log_lambdaadditional sampling-design-dependent term, added as-is
an N x Q matrix
SimpleSBM_fit_noCov$clone()The objects of this class are cloneable with this method.
SimpleSBM_fit_noCov$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.