SimpleSBM_fit_withCov: Internal class for a binary SBM fit under MAR sampling...

SimpleSBM_fit_withCovR Documentation

Internal class for a binary SBM fit under MAR sampling designs with covariates.

Description

It is not designed to be called directly by the user.

Super classes

sbm::SBM -> sbm::SimpleSBM -> SimpleSBM_fit -> SimpleSBM_fit_withCov

Active bindings

imputation

the matrix of imputed values

vExpec

double: variational approximation of the expectation complete log-likelihood

vExpec_corrected

double: variational approximation of the expectation complete log-likelihood with correction to be comparable with MNAR criteria

Methods

Public methods

Inherited methods

SimpleSBM_fit_withCov$update_parameters()

update parameters estimation (M-step) via Newton-Raphson: the M-step objective is a weighted logistic regression (concave), so Newton converges in a handful of iterations – no external optimizer is required.

Usage
SimpleSBM_fit_withCov$update_parameters(...)
Arguments
...

use for compatibility


SimpleSBM_fit_withCov$update_blocks()

update variational estimation of blocks (VE-step)

Usage
SimpleSBM_fit_withCov$update_blocks(...)
Arguments
...

use for compatibility


SimpleSBM_fit_withCov$polish_log_tau()

for each node, the complete-data log-likelihood it would contribute to each class if hard-assigned there (theta/beta/pi held fixed), used to decide node-swap moves in missSBM_fit$polish().

Usage
SimpleSBM_fit_withCov$polish_log_tau(log_lambda = 0)
Arguments
log_lambda

additional sampling-design-dependent term, added as-is

Returns

an N x Q matrix


SimpleSBM_fit_withCov$clone()

The objects of this class are cloneable with this method.

Usage
SimpleSBM_fit_withCov$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


missSBM documentation built on July 22, 2026, 1:07 a.m.