| blockDyadSampler | R Documentation |
Class for defining a block dyad sampler
networkSampling -> networkSampler -> dyadSampler -> blockDyadSampler
dfthe number of parameters of this sampling
blockDyadSampler$new()constructor for networkSampling
blockDyadSampler$new( parameters = NA, nbNodes = NA, directed = FALSE, clusters = NA )
parametersthe vector of parameters associated to the sampling at play
nbNodesnumber of nodes in the network
directedlogical, directed network of not
clustersa vector of class memberships
blockDyadSampler$clone()The objects of this class are cloneable with this method.
blockDyadSampler$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.