dyadSampler: Virtual class for all dyad-centered samplers

dyadSamplerR Documentation

Virtual class for all dyad-centered samplers

Description

Virtual class for all dyad-centered samplers

Super classes

networkSampling -> networkSampler -> dyadSampler

Methods

Public methods

Inherited methods

dyadSampler$new()

constructor for networkSampling

Usage
dyadSampler$new(type = NA, parameters = NA, nbNodes = NA, directed = FALSE)
Arguments
type

character for the type of sampling. must be in ("dyad", "covar-dyad", "node", "covar-node", "block-node", "block-dyad", "double-standard", "degree")

parameters

the vector of parameters associated to the sampling at play

nbNodes

number of nodes in the network

directed

logical, directed network of not


dyadSampler$clone()

The objects of this class are cloneable with this method.

Usage
dyadSampler$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


missSBM documentation built on July 22, 2026, 1:07 a.m.