| nodeSampling_fit | R Documentation |
Class for fitting a node sampling
networkSampling -> networkSamplingNodes_fit -> nodeSampling_fit
vExpecvariational expectation of the sampling
nodeSampling_fit$new()constructor
nodeSampling_fit$new(partlyObservedNetwork, ...)
partlyObservedNetworka object with class partlyObservedNetwork representing the observed data with possibly missing entries
...used for compatibility
nodeSampling_fit$clone()The objects of this class are cloneable with this method.
nodeSampling_fit$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.