Plot function for the various fields of a missSBM_fit: the fitted
SBM (network or connectivity), and a plot monitoring the optimization.
Arguments
- x
an object with class
missSBM_fit- type
the type specifies the field to plot, either "imputed", "expected", "meso", or "monitoring"
- dimLabels
: a list of two characters specifying the labels of the nodes. Default to
list(row= 'node',col = 'node'))- ...
additional parameters for S3 compatibility. Not used