simpleNodeSampler: Class for defining a simple node sampler

simpleNodeSamplerR Documentation

Class for defining a simple node sampler

Description

Class for defining a simple node sampler

Super classes

networkSampling -> networkSampler -> nodeSampler -> simpleNodeSampler

Methods

Public methods

Inherited methods

simpleNodeSampler$new()

constructor for networkSampling

Usage
simpleNodeSampler$new(
  parameters = NA,
  nbNodes = NA,
  directed = FALSE,
  covarMatrix = NULL,
  intercept = 0
)
Arguments
parameters

the vector of parameters associated to the sampling at play

nbNodes

number of nodes in the network

directed

logical, directed network of not

covarMatrix

a matrix of covariates used

intercept

double, intercept term used to compute the probability of sampling in the presence of covariates. Default 0.


simpleNodeSampler$clone()

The objects of this class are cloneable with this method.

Usage
simpleNodeSampler$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


missSBM documentation built on July 22, 2026, 1:07 a.m.