snowballSampler: Class for defining a snowball sampler

snowballSamplerR Documentation

Class for defining a snowball sampler

Description

Class for defining a snowball sampler

Super classes

networkSampling -> networkSampler -> nodeSampler -> snowballSampler

Methods

Public methods

Inherited methods

snowballSampler$new()

constructor for networkSampling

Usage
snowballSampler$new(parameters = NA, adjacencyMatrix = NA, directed = FALSE)
Arguments
parameters

the vector of parameters associated to the sampling at play

adjacencyMatrix

the adjacency matrix of the network

directed

logical, directed network of not


snowballSampler$clone()

The objects of this class are cloneable with this method.

Usage
snowballSampler$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


missSBM documentation built on July 22, 2026, 1:07 a.m.