R/R6Class-simpleSBM_fit.R
SimpleSBM_fit.RdIt is not designed to be called directly by the user; see the concrete variants
SimpleSBM_fit_noCov, SimpleSBM_fit_withCov and SimpleSBM_fit_MNAR.
sbm::SBM -> sbm::SimpleSBM -> SimpleSBM_fit
typethe type of SBM (distribution of edges values, network type, presence of covariates)
penaltydouble, value of the penalty term in ICL
entropydouble, value of the entropy due to the clustering distribution
loglikdouble: approximation of the log-likelihood (variational lower bound) reached
ICLdouble: value of the integrated classification log-likelihood
SimpleSBM_fit$new()constructor for simpleSBM_fit for missSBM purpose
SimpleSBM_fit$new(networkData, clusterInit, covarList = list())networkDataa structure to store network under missing data condition: either a matrix possibly with NA, or a missSBM:::partlyObservedNetwork
clusterInitInitial clustering: a vector with size ncol(adjacencyMatrix), providing a user-defined clustering with nbBlocks levels.
covarListAn optional list with M entries (the M covariates).
SimpleSBM_fit$doVEM()method to perform estimation via variational EM
thresholdstop when an optimization step changes the objective function by less than threshold. Default is 1e-4.
maxIterV-EM algorithm stops when the number of iteration exceeds maxIter. Default is 10
fixPointIternumber of fix-point iterations in the Variational E step. Default is 5.
tracelogical for verbosity. Default is FALSE.
SimpleSBM_fit$get_state()a lightweight snapshot of the mutable VEM state (as opposed to clone(),
which duplicates the whole object, including the – possibly large – network data)