It is not designed to be called directly by the user.
Active bindings
vExpec
double: variational approximation of the expectation complete log-likelihood
Methods
Inherited methods
SimpleSBM_MNAR_noCov$new()
constructor for simpleSBM_fit for missSBM purpose
Usage
SimpleSBM_MNAR_noCov$new(networkData, clusterInit)
Arguments
networkData
a structure to store network under missing data condition: either a matrix possibly with NA, or a missSBM:::partlyObservedNetwork
clusterInit
Initial clustering: a vector with size ncol(adjacencyMatrix), providing a user-defined clustering with nbBlocks levels.
SimpleSBM_MNAR_noCov$update_parameters()
update parameters estimation (M-step)
Usage
SimpleSBM_MNAR_noCov$update_parameters(nu = NULL)
Arguments
nu
currently imputed values
SimpleSBM_MNAR_noCov$update_blocks()
update variational estimation of blocks (VE-step)
Usage
SimpleSBM_MNAR_noCov$update_blocks(log_lambda = 0)
Arguments
log_lambda
additional term sampling dependent used to de-bias estimation of tau
SimpleSBM_MNAR_noCov$clone()
The objects of this class are cloneable with this method.
Usage
SimpleSBM_MNAR_noCov$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.