It is not designed to be called directly by the user.

Super classes

sbm::SBM -> sbm::SimpleSBM -> SimpleSBM_fit -> SimpleSBM_fit_noCov

Active bindings

imputation

the matrix of imputed values

vExpec

double: variational approximation of the expectation complete log-likelihood

vExpec_corrected

double: variational approximation of the expectation complete log-likelihood with correction to be comparable with MNAR criteria

Methods

Inherited methods


SimpleSBM_fit_noCov$update_parameters()

update parameters estimation (M-step)

Usage

SimpleSBM_fit_noCov$update_parameters(...)

Arguments

...

additional arguments, only required for MNAR cases


SimpleSBM_fit_noCov$update_blocks()

update variational estimation of blocks (VE-step)

Usage

SimpleSBM_fit_noCov$update_blocks(...)

Arguments

...

additional arguments, only required for MNAR cases


SimpleSBM_fit_noCov$clone()

The objects of this class are cloneable with this method.

Usage

SimpleSBM_fit_noCov$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.