R/R6Class-simpleSBM_fit.R
SimpleSBM_fit_withCov.RdIt is not designed to be called directly by the user.
sbm::SBM -> sbm::SimpleSBM -> SimpleSBM_fit -> SimpleSBM_fit_withCov
imputationthe matrix of imputed values
vExpecdouble: variational approximation of the expectation complete log-likelihood
vExpec_correcteddouble: variational approximation of the expectation complete log-likelihood with correction to be comparable with MNAR criteria
Inherited methods
SimpleSBM_fit_withCov$update_parameters()update parameters estimation (M-step) via Newton-Raphson: the M-step objective is a weighted logistic regression (concave), so Newton converges in a handful of iterations – no external optimizer is required.