| dyadSampler | R Documentation |
Virtual class for all dyad-centered samplers
networkSampling -> networkSampler -> dyadSampler
dyadSampler$new()constructor for networkSampling
dyadSampler$new(type = NA, parameters = NA, nbNodes = NA, directed = FALSE)
typecharacter for the type of sampling. must be in ("dyad", "covar-dyad", "node", "covar-node", "block-node", "block-dyad", "double-standard", "degree")
parametersthe vector of parameters associated to the sampling at play
nbNodesnumber of nodes in the network
directedlogical, directed network of not
dyadSampler$clone()The objects of this class are cloneable with this method.
dyadSampler$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.