this virtual class is the mother of all subtypes of networkSampling (either sampler or fit) It is used to define a sampling model for a network. It has a rSampling method which takes an adjacency matrix as an input and send back an object with class partlyObservedNetwork.
Active bindings
typea character for the type of sampling
parametersthe vector of parameters associated with the sampling at play
dfthe number of entries in the vector of parameters
Methods
networkSampling$new()
constructor for networkSampling
Usage
networkSampling$new(type = NA, parameters = NA)networkSampling$show()
show method
Usage
networkSampling$show(
type = paste0(private$name, "-model for network sampling\n")
)