| snowballSampler | R Documentation |
Class for defining a snowball sampler
networkSampling -> networkSampler -> nodeSampler -> snowballSampler
snowballSampler$new()constructor for networkSampling
snowballSampler$new(parameters = NA, adjacencyMatrix = NA, directed = FALSE)
parametersthe vector of parameters associated to the sampling at play
adjacencyMatrixthe adjacency matrix of the network
directedlogical, directed network of not
snowballSampler$clone()The objects of this class are cloneable with this method.
snowballSampler$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.